# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepShape module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepshape.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepShape
else:
    import _RWStepShape

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepShape.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepShape.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepShape.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepShape.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepShape.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepShape.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepShape.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepShape.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepShape.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepShape.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepShape.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepShape.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepShape.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepShape.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepShape.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepShape.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepShape.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepShape:
_RWStepShape.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepShape.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepShape
import OCC.Core.StepGeom
import OCC.Core.StepRepr
import OCC.Core.StepBasic

from enum import IntEnum
from OCC.Core.Exception import *



class RWStepShape_RWAdvancedBrepShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWAdvancedBrepShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWAdvancedBrepShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_AdvancedBrepShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAdvancedBrepShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_AdvancedBrepShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAdvancedBrepShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_AdvancedBrepShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAdvancedBrepShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWAdvancedBrepShapeRepresentation

# Register RWStepShape_RWAdvancedBrepShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWAdvancedBrepShapeRepresentation_swigregister(RWStepShape_RWAdvancedBrepShapeRepresentation)

class RWStepShape_RWAdvancedFace(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWAdvancedFace_swiginit(self, _RWStepShape.new_RWStepShape_RWAdvancedFace(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_AdvancedFace

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAdvancedFace_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_AdvancedFace
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAdvancedFace_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_AdvancedFace

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAdvancedFace_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWAdvancedFace

# Register RWStepShape_RWAdvancedFace in _RWStepShape:
_RWStepShape.RWStepShape_RWAdvancedFace_swigregister(RWStepShape_RWAdvancedFace)

class RWStepShape_RWAngularLocation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWAngularLocation_swiginit(self, _RWStepShape.new_RWStepShape_RWAngularLocation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads angularlocation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_AngularLocation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAngularLocation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_AngularLocation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAngularLocation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes angularlocation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_AngularLocation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAngularLocation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWAngularLocation

# Register RWStepShape_RWAngularLocation in _RWStepShape:
_RWStepShape.RWStepShape_RWAngularLocation_swigregister(RWStepShape_RWAngularLocation)

class RWStepShape_RWAngularSize(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWAngularSize_swiginit(self, _RWStepShape.new_RWStepShape_RWAngularSize(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads angularsize.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_AngularSize

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAngularSize_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_AngularSize
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAngularSize_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes angularsize.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_AngularSize

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWAngularSize_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWAngularSize

# Register RWStepShape_RWAngularSize in _RWStepShape:
_RWStepShape.RWStepShape_RWAngularSize_swigregister(RWStepShape_RWAngularSize)

class RWStepShape_RWBlock(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWBlock_swiginit(self, _RWStepShape.new_RWStepShape_RWBlock(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Block

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBlock_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_Block
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBlock_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Block

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBlock_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWBlock

# Register RWStepShape_RWBlock in _RWStepShape:
_RWStepShape.RWStepShape_RWBlock_swigregister(RWStepShape_RWBlock)

class RWStepShape_RWBooleanResult(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWBooleanResult_swiginit(self, _RWStepShape.new_RWStepShape_RWBooleanResult(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_BooleanResult

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBooleanResult_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_BooleanResult
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBooleanResult_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_BooleanResult

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBooleanResult_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWBooleanResult

# Register RWStepShape_RWBooleanResult in _RWStepShape:
_RWStepShape.RWStepShape_RWBooleanResult_swigregister(RWStepShape_RWBooleanResult)

class RWStepShape_RWBoxDomain(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWBoxDomain_swiginit(self, _RWStepShape.new_RWStepShape_RWBoxDomain(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_BoxDomain

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBoxDomain_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_BoxDomain
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBoxDomain_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_BoxDomain

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBoxDomain_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWBoxDomain

# Register RWStepShape_RWBoxDomain in _RWStepShape:
_RWStepShape.RWStepShape_RWBoxDomain_swigregister(RWStepShape_RWBoxDomain)

class RWStepShape_RWBoxedHalfSpace(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWBoxedHalfSpace_swiginit(self, _RWStepShape.new_RWStepShape_RWBoxedHalfSpace(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_BoxedHalfSpace

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBoxedHalfSpace_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_BoxedHalfSpace
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBoxedHalfSpace_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_BoxedHalfSpace

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBoxedHalfSpace_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWBoxedHalfSpace

# Register RWStepShape_RWBoxedHalfSpace in _RWStepShape:
_RWStepShape.RWStepShape_RWBoxedHalfSpace_swigregister(RWStepShape_RWBoxedHalfSpace)

class RWStepShape_RWBrepWithVoids(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWBrepWithVoids_swiginit(self, _RWStepShape.new_RWStepShape_RWBrepWithVoids(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_BrepWithVoids
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBrepWithVoids_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_BrepWithVoids

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBrepWithVoids_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_BrepWithVoids
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBrepWithVoids_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_BrepWithVoids

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWBrepWithVoids_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWBrepWithVoids

# Register RWStepShape_RWBrepWithVoids in _RWStepShape:
_RWStepShape.RWStepShape_RWBrepWithVoids_swigregister(RWStepShape_RWBrepWithVoids)

class RWStepShape_RWClosedShell(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWClosedShell_swiginit(self, _RWStepShape.new_RWStepShape_RWClosedShell(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ClosedShell

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWClosedShell_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ClosedShell
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWClosedShell_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ClosedShell

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWClosedShell_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWClosedShell

# Register RWStepShape_RWClosedShell in _RWStepShape:
_RWStepShape.RWStepShape_RWClosedShell_swigregister(RWStepShape_RWClosedShell)

class RWStepShape_RWCompoundShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWCompoundShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWCompoundShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads compoundshaperepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_CompoundShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWCompoundShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_CompoundShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWCompoundShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes compoundshaperepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_CompoundShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWCompoundShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWCompoundShapeRepresentation

# Register RWStepShape_RWCompoundShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWCompoundShapeRepresentation_swigregister(RWStepShape_RWCompoundShapeRepresentation)

class RWStepShape_RWConnectedEdgeSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWConnectedEdgeSet_swiginit(self, _RWStepShape.new_RWStepShape_RWConnectedEdgeSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads connectededgeset.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ConnectedEdgeSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedEdgeSet_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_ConnectedEdgeSet
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedEdgeSet_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes connectededgeset.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ConnectedEdgeSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedEdgeSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWConnectedEdgeSet

# Register RWStepShape_RWConnectedEdgeSet in _RWStepShape:
_RWStepShape.RWStepShape_RWConnectedEdgeSet_swigregister(RWStepShape_RWConnectedEdgeSet)

class RWStepShape_RWConnectedFaceSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWConnectedFaceSet_swiginit(self, _RWStepShape.new_RWStepShape_RWConnectedFaceSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ConnectedFaceSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedFaceSet_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ConnectedFaceSet
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedFaceSet_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ConnectedFaceSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedFaceSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWConnectedFaceSet

# Register RWStepShape_RWConnectedFaceSet in _RWStepShape:
_RWStepShape.RWStepShape_RWConnectedFaceSet_swigregister(RWStepShape_RWConnectedFaceSet)

class RWStepShape_RWConnectedFaceShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWConnectedFaceShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWConnectedFaceShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads connectedfaceshaperepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ConnectedFaceShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedFaceShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_ConnectedFaceShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedFaceShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes connectedfaceshaperepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ConnectedFaceShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedFaceShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWConnectedFaceShapeRepresentation

# Register RWStepShape_RWConnectedFaceShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWConnectedFaceShapeRepresentation_swigregister(RWStepShape_RWConnectedFaceShapeRepresentation)

class RWStepShape_RWConnectedFaceSubSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWConnectedFaceSubSet_swiginit(self, _RWStepShape.new_RWStepShape_RWConnectedFaceSubSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads connectedfacesubset.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ConnectedFaceSubSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedFaceSubSet_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_ConnectedFaceSubSet
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedFaceSubSet_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes connectedfacesubset.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ConnectedFaceSubSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWConnectedFaceSubSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWConnectedFaceSubSet

# Register RWStepShape_RWConnectedFaceSubSet in _RWStepShape:
_RWStepShape.RWStepShape_RWConnectedFaceSubSet_swigregister(RWStepShape_RWConnectedFaceSubSet)

class RWStepShape_RWContextDependentShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWContextDependentShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWContextDependentShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ContextDependentShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWContextDependentShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ContextDependentShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWContextDependentShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ContextDependentShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWContextDependentShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWContextDependentShapeRepresentation

# Register RWStepShape_RWContextDependentShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWContextDependentShapeRepresentation_swigregister(RWStepShape_RWContextDependentShapeRepresentation)

class RWStepShape_RWCsgShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWCsgShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWCsgShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_CsgShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWCsgShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_CsgShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWCsgShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_CsgShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWCsgShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWCsgShapeRepresentation

# Register RWStepShape_RWCsgShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWCsgShapeRepresentation_swigregister(RWStepShape_RWCsgShapeRepresentation)

class RWStepShape_RWCsgSolid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWCsgSolid_swiginit(self, _RWStepShape.new_RWStepShape_RWCsgSolid(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_CsgSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWCsgSolid_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_CsgSolid
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWCsgSolid_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_CsgSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWCsgSolid_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWCsgSolid

# Register RWStepShape_RWCsgSolid in _RWStepShape:
_RWStepShape.RWStepShape_RWCsgSolid_swigregister(RWStepShape_RWCsgSolid)

class RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_DefinitionalRepresentationAndShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_DefinitionalRepresentationAndShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_DefinitionalRepresentationAndShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation

# Register RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation_swigregister(RWStepShape_RWDefinitionalRepresentationAndShapeRepresentation)

class RWStepShape_RWDimensionalCharacteristicRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWDimensionalCharacteristicRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWDimensionalCharacteristicRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads dimensionalcharacteristicrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_DimensionalCharacteristicRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalCharacteristicRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_DimensionalCharacteristicRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalCharacteristicRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes dimensionalcharacteristicrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_DimensionalCharacteristicRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalCharacteristicRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWDimensionalCharacteristicRepresentation

# Register RWStepShape_RWDimensionalCharacteristicRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWDimensionalCharacteristicRepresentation_swigregister(RWStepShape_RWDimensionalCharacteristicRepresentation)

class RWStepShape_RWDimensionalLocation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWDimensionalLocation_swiginit(self, _RWStepShape.new_RWStepShape_RWDimensionalLocation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads dimensionallocation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_DimensionalLocation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalLocation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_DimensionalLocation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalLocation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes dimensionallocation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_DimensionalLocation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalLocation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWDimensionalLocation

# Register RWStepShape_RWDimensionalLocation in _RWStepShape:
_RWStepShape.RWStepShape_RWDimensionalLocation_swigregister(RWStepShape_RWDimensionalLocation)

class RWStepShape_RWDimensionalLocationWithPath(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWDimensionalLocationWithPath_swiginit(self, _RWStepShape.new_RWStepShape_RWDimensionalLocationWithPath(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads dimensionallocationwithpath.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_DimensionalLocationWithPath

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalLocationWithPath_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_DimensionalLocationWithPath
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalLocationWithPath_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes dimensionallocationwithpath.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_DimensionalLocationWithPath

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalLocationWithPath_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWDimensionalLocationWithPath

# Register RWStepShape_RWDimensionalLocationWithPath in _RWStepShape:
_RWStepShape.RWStepShape_RWDimensionalLocationWithPath_swigregister(RWStepShape_RWDimensionalLocationWithPath)

class RWStepShape_RWDimensionalSize(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWDimensionalSize_swiginit(self, _RWStepShape.new_RWStepShape_RWDimensionalSize(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads dimensionalsize.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_DimensionalSize

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalSize_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_DimensionalSize
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalSize_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes dimensionalsize.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_DimensionalSize

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalSize_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWDimensionalSize

# Register RWStepShape_RWDimensionalSize in _RWStepShape:
_RWStepShape.RWStepShape_RWDimensionalSize_swigregister(RWStepShape_RWDimensionalSize)

class RWStepShape_RWDimensionalSizeWithPath(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWDimensionalSizeWithPath_swiginit(self, _RWStepShape.new_RWStepShape_RWDimensionalSizeWithPath(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads dimensionalsizewithpath.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_DimensionalSizeWithPath

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalSizeWithPath_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_DimensionalSizeWithPath
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalSizeWithPath_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes dimensionalsizewithpath.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_DimensionalSizeWithPath

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWDimensionalSizeWithPath_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWDimensionalSizeWithPath

# Register RWStepShape_RWDimensionalSizeWithPath in _RWStepShape:
_RWStepShape.RWStepShape_RWDimensionalSizeWithPath_swigregister(RWStepShape_RWDimensionalSizeWithPath)

class RWStepShape_RWEdge(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWEdge_swiginit(self, _RWStepShape.new_RWStepShape_RWEdge(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Edge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdge_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_Edge
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdge_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Edge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdge_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWEdge

# Register RWStepShape_RWEdge in _RWStepShape:
_RWStepShape.RWStepShape_RWEdge_swigregister(RWStepShape_RWEdge)

class RWStepShape_RWEdgeBasedWireframeModel(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWEdgeBasedWireframeModel_swiginit(self, _RWStepShape.new_RWStepShape_RWEdgeBasedWireframeModel(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads edgebasedwireframemodel.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_EdgeBasedWireframeModel

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeBasedWireframeModel_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_EdgeBasedWireframeModel
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeBasedWireframeModel_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes edgebasedwireframemodel.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_EdgeBasedWireframeModel

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeBasedWireframeModel_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWEdgeBasedWireframeModel

# Register RWStepShape_RWEdgeBasedWireframeModel in _RWStepShape:
_RWStepShape.RWStepShape_RWEdgeBasedWireframeModel_swigregister(RWStepShape_RWEdgeBasedWireframeModel)

class RWStepShape_RWEdgeBasedWireframeShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWEdgeBasedWireframeShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWEdgeBasedWireframeShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads edgebasedwireframeshaperepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_EdgeBasedWireframeShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeBasedWireframeShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_EdgeBasedWireframeShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeBasedWireframeShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes edgebasedwireframeshaperepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_EdgeBasedWireframeShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeBasedWireframeShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWEdgeBasedWireframeShapeRepresentation

# Register RWStepShape_RWEdgeBasedWireframeShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWEdgeBasedWireframeShapeRepresentation_swigregister(RWStepShape_RWEdgeBasedWireframeShapeRepresentation)

class RWStepShape_RWEdgeCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWEdgeCurve_swiginit(self, _RWStepShape.new_RWStepShape_RWEdgeCurve(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_EdgeCurve
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeCurve_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_EdgeCurve

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_EdgeCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_EdgeCurve

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWEdgeCurve

# Register RWStepShape_RWEdgeCurve in _RWStepShape:
_RWStepShape.RWStepShape_RWEdgeCurve_swigregister(RWStepShape_RWEdgeCurve)

class RWStepShape_RWEdgeLoop(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWEdgeLoop_swiginit(self, _RWStepShape.new_RWStepShape_RWEdgeLoop(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_EdgeLoop
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeLoop_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_EdgeLoop

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeLoop_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_EdgeLoop
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeLoop_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_EdgeLoop

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWEdgeLoop_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWEdgeLoop

# Register RWStepShape_RWEdgeLoop in _RWStepShape:
_RWStepShape.RWStepShape_RWEdgeLoop_swigregister(RWStepShape_RWEdgeLoop)

class RWStepShape_RWExtrudedAreaSolid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWExtrudedAreaSolid_swiginit(self, _RWStepShape.new_RWStepShape_RWExtrudedAreaSolid(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ExtrudedAreaSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWExtrudedAreaSolid_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ExtrudedAreaSolid
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWExtrudedAreaSolid_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ExtrudedAreaSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWExtrudedAreaSolid_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWExtrudedAreaSolid

# Register RWStepShape_RWExtrudedAreaSolid in _RWStepShape:
_RWStepShape.RWStepShape_RWExtrudedAreaSolid_swigregister(RWStepShape_RWExtrudedAreaSolid)

class RWStepShape_RWExtrudedFaceSolid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWExtrudedFaceSolid_swiginit(self, _RWStepShape.new_RWStepShape_RWExtrudedFaceSolid(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ExtrudedFaceSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWExtrudedFaceSolid_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ExtrudedFaceSolid
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWExtrudedFaceSolid_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ExtrudedFaceSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWExtrudedFaceSolid_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWExtrudedFaceSolid

# Register RWStepShape_RWExtrudedFaceSolid in _RWStepShape:
_RWStepShape.RWStepShape_RWExtrudedFaceSolid_swigregister(RWStepShape_RWExtrudedFaceSolid)

class RWStepShape_RWFace(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWFace_swiginit(self, _RWStepShape.new_RWStepShape_RWFace(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Face

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFace_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_Face
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFace_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Face

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFace_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWFace

# Register RWStepShape_RWFace in _RWStepShape:
_RWStepShape.RWStepShape_RWFace_swigregister(RWStepShape_RWFace)

class RWStepShape_RWFaceBasedSurfaceModel(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWFaceBasedSurfaceModel_swiginit(self, _RWStepShape.new_RWStepShape_RWFaceBasedSurfaceModel(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads facebasedsurfacemodel.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_FaceBasedSurfaceModel

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceBasedSurfaceModel_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_FaceBasedSurfaceModel
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceBasedSurfaceModel_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes facebasedsurfacemodel.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_FaceBasedSurfaceModel

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceBasedSurfaceModel_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWFaceBasedSurfaceModel

# Register RWStepShape_RWFaceBasedSurfaceModel in _RWStepShape:
_RWStepShape.RWStepShape_RWFaceBasedSurfaceModel_swigregister(RWStepShape_RWFaceBasedSurfaceModel)

class RWStepShape_RWFaceBound(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWFaceBound_swiginit(self, _RWStepShape.new_RWStepShape_RWFaceBound(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_FaceBound
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceBound_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_FaceBound

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceBound_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_FaceBound
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceBound_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_FaceBound

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceBound_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWFaceBound

# Register RWStepShape_RWFaceBound in _RWStepShape:
_RWStepShape.RWStepShape_RWFaceBound_swigregister(RWStepShape_RWFaceBound)

class RWStepShape_RWFaceOuterBound(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWFaceOuterBound_swiginit(self, _RWStepShape.new_RWStepShape_RWFaceOuterBound(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_FaceOuterBound

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceOuterBound_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_FaceOuterBound
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceOuterBound_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_FaceOuterBound

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceOuterBound_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWFaceOuterBound

# Register RWStepShape_RWFaceOuterBound in _RWStepShape:
_RWStepShape.RWStepShape_RWFaceOuterBound_swigregister(RWStepShape_RWFaceOuterBound)

class RWStepShape_RWFaceSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWFaceSurface_swiginit(self, _RWStepShape.new_RWStepShape_RWFaceSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_FaceSurface

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_FaceSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_FaceSurface

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFaceSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWFaceSurface

# Register RWStepShape_RWFaceSurface in _RWStepShape:
_RWStepShape.RWStepShape_RWFaceSurface_swigregister(RWStepShape_RWFaceSurface)

class RWStepShape_RWFacetedBrep(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWFacetedBrep_swiginit(self, _RWStepShape.new_RWStepShape_RWFacetedBrep(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_FacetedBrep

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFacetedBrep_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_FacetedBrep
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFacetedBrep_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_FacetedBrep

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFacetedBrep_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWFacetedBrep

# Register RWStepShape_RWFacetedBrep in _RWStepShape:
_RWStepShape.RWStepShape_RWFacetedBrep_swigregister(RWStepShape_RWFacetedBrep)

class RWStepShape_RWFacetedBrepAndBrepWithVoids(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWFacetedBrepAndBrepWithVoids_swiginit(self, _RWStepShape.new_RWStepShape_RWFacetedBrepAndBrepWithVoids(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_FacetedBrepAndBrepWithVoids

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFacetedBrepAndBrepWithVoids_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_FacetedBrepAndBrepWithVoids
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFacetedBrepAndBrepWithVoids_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_FacetedBrepAndBrepWithVoids

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFacetedBrepAndBrepWithVoids_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWFacetedBrepAndBrepWithVoids

# Register RWStepShape_RWFacetedBrepAndBrepWithVoids in _RWStepShape:
_RWStepShape.RWStepShape_RWFacetedBrepAndBrepWithVoids_swigregister(RWStepShape_RWFacetedBrepAndBrepWithVoids)

class RWStepShape_RWFacetedBrepShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWFacetedBrepShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWFacetedBrepShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_FacetedBrepShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFacetedBrepShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_FacetedBrepShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFacetedBrepShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_FacetedBrepShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWFacetedBrepShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWFacetedBrepShapeRepresentation

# Register RWStepShape_RWFacetedBrepShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWFacetedBrepShapeRepresentation_swigregister(RWStepShape_RWFacetedBrepShapeRepresentation)

class RWStepShape_RWGeometricCurveSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWGeometricCurveSet_swiginit(self, _RWStepShape.new_RWStepShape_RWGeometricCurveSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_GeometricCurveSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricCurveSet_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_GeometricCurveSet
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricCurveSet_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_GeometricCurveSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricCurveSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWGeometricCurveSet

# Register RWStepShape_RWGeometricCurveSet in _RWStepShape:
_RWStepShape.RWStepShape_RWGeometricCurveSet_swigregister(RWStepShape_RWGeometricCurveSet)

class RWStepShape_RWGeometricSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWGeometricSet_swiginit(self, _RWStepShape.new_RWStepShape_RWGeometricSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_GeometricSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricSet_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_GeometricSet
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricSet_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_GeometricSet

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWGeometricSet

# Register RWStepShape_RWGeometricSet in _RWStepShape:
_RWStepShape.RWStepShape_RWGeometricSet_swigregister(RWStepShape_RWGeometricSet)

class RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_GeometricallyBoundedSurfaceShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_GeometricallyBoundedSurfaceShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_GeometricallyBoundedSurfaceShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation

# Register RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation_swigregister(RWStepShape_RWGeometricallyBoundedSurfaceShapeRepresentation)

class RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_GeometricallyBoundedWireframeShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_GeometricallyBoundedWireframeShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_GeometricallyBoundedWireframeShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation

# Register RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation_swigregister(RWStepShape_RWGeometricallyBoundedWireframeShapeRepresentation)

class RWStepShape_RWHalfSpaceSolid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWHalfSpaceSolid_swiginit(self, _RWStepShape.new_RWStepShape_RWHalfSpaceSolid(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_HalfSpaceSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWHalfSpaceSolid_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_HalfSpaceSolid
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWHalfSpaceSolid_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_HalfSpaceSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWHalfSpaceSolid_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWHalfSpaceSolid

# Register RWStepShape_RWHalfSpaceSolid in _RWStepShape:
_RWStepShape.RWStepShape_RWHalfSpaceSolid_swigregister(RWStepShape_RWHalfSpaceSolid)

class RWStepShape_RWLimitsAndFits(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWLimitsAndFits_swiginit(self, _RWStepShape.new_RWStepShape_RWLimitsAndFits(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_LimitsAndFits

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWLimitsAndFits_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_LimitsAndFits

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWLimitsAndFits_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWLimitsAndFits

# Register RWStepShape_RWLimitsAndFits in _RWStepShape:
_RWStepShape.RWStepShape_RWLimitsAndFits_swigregister(RWStepShape_RWLimitsAndFits)

class RWStepShape_RWLoop(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWLoop_swiginit(self, _RWStepShape.new_RWStepShape_RWLoop(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Loop

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWLoop_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Loop

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWLoop_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWLoop

# Register RWStepShape_RWLoop in _RWStepShape:
_RWStepShape.RWStepShape_RWLoop_swigregister(RWStepShape_RWLoop)

class RWStepShape_RWLoopAndPath(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWLoopAndPath_swiginit(self, _RWStepShape.new_RWStepShape_RWLoopAndPath(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_LoopAndPath

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWLoopAndPath_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_LoopAndPath
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWLoopAndPath_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_LoopAndPath

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWLoopAndPath_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWLoopAndPath

# Register RWStepShape_RWLoopAndPath in _RWStepShape:
_RWStepShape.RWStepShape_RWLoopAndPath_swigregister(RWStepShape_RWLoopAndPath)

class RWStepShape_RWManifoldSolidBrep(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWManifoldSolidBrep_swiginit(self, _RWStepShape.new_RWStepShape_RWManifoldSolidBrep(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ManifoldSolidBrep

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWManifoldSolidBrep_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ManifoldSolidBrep
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWManifoldSolidBrep_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ManifoldSolidBrep

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWManifoldSolidBrep_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWManifoldSolidBrep

# Register RWStepShape_RWManifoldSolidBrep in _RWStepShape:
_RWStepShape.RWStepShape_RWManifoldSolidBrep_swigregister(RWStepShape_RWManifoldSolidBrep)

class RWStepShape_RWManifoldSurfaceShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWManifoldSurfaceShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWManifoldSurfaceShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ManifoldSurfaceShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWManifoldSurfaceShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ManifoldSurfaceShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWManifoldSurfaceShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ManifoldSurfaceShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWManifoldSurfaceShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWManifoldSurfaceShapeRepresentation

# Register RWStepShape_RWManifoldSurfaceShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWManifoldSurfaceShapeRepresentation_swigregister(RWStepShape_RWManifoldSurfaceShapeRepresentation)

class RWStepShape_RWMeasureQualification(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWMeasureQualification_swiginit(self, _RWStepShape.new_RWStepShape_RWMeasureQualification(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_MeasureQualification

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWMeasureQualification_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_MeasureQualification
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWMeasureQualification_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_MeasureQualification

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWMeasureQualification_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWMeasureQualification

# Register RWStepShape_RWMeasureQualification in _RWStepShape:
_RWStepShape.RWStepShape_RWMeasureQualification_swigregister(RWStepShape_RWMeasureQualification)

class RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem_swiginit(self, _RWStepShape.new_RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_MeasureRepresentationItemAndQualifiedRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_MeasureRepresentationItemAndQualifiedRepresentationItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_MeasureRepresentationItemAndQualifiedRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem

# Register RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem in _RWStepShape:
_RWStepShape.RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem_swigregister(RWStepShape_RWMeasureRepresentationItemAndQualifiedRepresentationItem)

class RWStepShape_RWNonManifoldSurfaceShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWNonManifoldSurfaceShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWNonManifoldSurfaceShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads nonmanifoldsurfaceshaperepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_NonManifoldSurfaceShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWNonManifoldSurfaceShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_NonManifoldSurfaceShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWNonManifoldSurfaceShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes nonmanifoldsurfaceshaperepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_NonManifoldSurfaceShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWNonManifoldSurfaceShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWNonManifoldSurfaceShapeRepresentation

# Register RWStepShape_RWNonManifoldSurfaceShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWNonManifoldSurfaceShapeRepresentation_swigregister(RWStepShape_RWNonManifoldSurfaceShapeRepresentation)

class RWStepShape_RWOpenShell(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWOpenShell_swiginit(self, _RWStepShape.new_RWStepShape_RWOpenShell(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_OpenShell

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOpenShell_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_OpenShell
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOpenShell_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_OpenShell

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOpenShell_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWOpenShell

# Register RWStepShape_RWOpenShell in _RWStepShape:
_RWStepShape.RWStepShape_RWOpenShell_swigregister(RWStepShape_RWOpenShell)

class RWStepShape_RWOrientedClosedShell(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWOrientedClosedShell_swiginit(self, _RWStepShape.new_RWStepShape_RWOrientedClosedShell(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_OrientedClosedShell

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedClosedShell_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_OrientedClosedShell
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedClosedShell_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_OrientedClosedShell

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedClosedShell_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWOrientedClosedShell

# Register RWStepShape_RWOrientedClosedShell in _RWStepShape:
_RWStepShape.RWStepShape_RWOrientedClosedShell_swigregister(RWStepShape_RWOrientedClosedShell)

class RWStepShape_RWOrientedEdge(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWOrientedEdge_swiginit(self, _RWStepShape.new_RWStepShape_RWOrientedEdge(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_OrientedEdge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedEdge_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_OrientedEdge
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedEdge_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_OrientedEdge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedEdge_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWOrientedEdge

# Register RWStepShape_RWOrientedEdge in _RWStepShape:
_RWStepShape.RWStepShape_RWOrientedEdge_swigregister(RWStepShape_RWOrientedEdge)

class RWStepShape_RWOrientedFace(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWOrientedFace_swiginit(self, _RWStepShape.new_RWStepShape_RWOrientedFace(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_OrientedFace

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedFace_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_OrientedFace
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedFace_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_OrientedFace

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedFace_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWOrientedFace

# Register RWStepShape_RWOrientedFace in _RWStepShape:
_RWStepShape.RWStepShape_RWOrientedFace_swigregister(RWStepShape_RWOrientedFace)

class RWStepShape_RWOrientedOpenShell(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWOrientedOpenShell_swiginit(self, _RWStepShape.new_RWStepShape_RWOrientedOpenShell(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_OrientedOpenShell

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedOpenShell_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_OrientedOpenShell
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedOpenShell_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_OrientedOpenShell

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedOpenShell_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWOrientedOpenShell

# Register RWStepShape_RWOrientedOpenShell in _RWStepShape:
_RWStepShape.RWStepShape_RWOrientedOpenShell_swigregister(RWStepShape_RWOrientedOpenShell)

class RWStepShape_RWOrientedPath(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWOrientedPath_swiginit(self, _RWStepShape.new_RWStepShape_RWOrientedPath(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_OrientedPath

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedPath_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_OrientedPath
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedPath_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_OrientedPath

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWOrientedPath_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWOrientedPath

# Register RWStepShape_RWOrientedPath in _RWStepShape:
_RWStepShape.RWStepShape_RWOrientedPath_swigregister(RWStepShape_RWOrientedPath)

class RWStepShape_RWPath(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWPath_swiginit(self, _RWStepShape.new_RWStepShape_RWPath(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Path

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPath_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_Path
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPath_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Path

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPath_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWPath

# Register RWStepShape_RWPath in _RWStepShape:
_RWStepShape.RWStepShape_RWPath_swigregister(RWStepShape_RWPath)

class RWStepShape_RWPlusMinusTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWPlusMinusTolerance_swiginit(self, _RWStepShape.new_RWStepShape_RWPlusMinusTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_PlusMinusTolerance

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPlusMinusTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_PlusMinusTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPlusMinusTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_PlusMinusTolerance

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPlusMinusTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWPlusMinusTolerance

# Register RWStepShape_RWPlusMinusTolerance in _RWStepShape:
_RWStepShape.RWStepShape_RWPlusMinusTolerance_swigregister(RWStepShape_RWPlusMinusTolerance)

class RWStepShape_RWPointRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWPointRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWPointRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads pointrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_PointRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPointRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_PointRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPointRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes pointrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_PointRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPointRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWPointRepresentation

# Register RWStepShape_RWPointRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWPointRepresentation_swigregister(RWStepShape_RWPointRepresentation)

class RWStepShape_RWPolyLoop(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWPolyLoop_swiginit(self, _RWStepShape.new_RWStepShape_RWPolyLoop(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_PolyLoop

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPolyLoop_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_PolyLoop
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPolyLoop_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_PolyLoop

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPolyLoop_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWPolyLoop

# Register RWStepShape_RWPolyLoop in _RWStepShape:
_RWStepShape.RWStepShape_RWPolyLoop_swigregister(RWStepShape_RWPolyLoop)

class RWStepShape_RWPrecisionQualifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWPrecisionQualifier_swiginit(self, _RWStepShape.new_RWStepShape_RWPrecisionQualifier(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_PrecisionQualifier

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPrecisionQualifier_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_PrecisionQualifier

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWPrecisionQualifier_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWPrecisionQualifier

# Register RWStepShape_RWPrecisionQualifier in _RWStepShape:
_RWStepShape.RWStepShape_RWPrecisionQualifier_swigregister(RWStepShape_RWPrecisionQualifier)

class RWStepShape_RWQualifiedRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWQualifiedRepresentationItem_swiginit(self, _RWStepShape.new_RWStepShape_RWQualifiedRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_QualifiedRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWQualifiedRepresentationItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_QualifiedRepresentationItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWQualifiedRepresentationItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_QualifiedRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWQualifiedRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWQualifiedRepresentationItem

# Register RWStepShape_RWQualifiedRepresentationItem in _RWStepShape:
_RWStepShape.RWStepShape_RWQualifiedRepresentationItem_swigregister(RWStepShape_RWQualifiedRepresentationItem)

class RWStepShape_RWRevolvedAreaSolid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWRevolvedAreaSolid_swiginit(self, _RWStepShape.new_RWStepShape_RWRevolvedAreaSolid(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_RevolvedAreaSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRevolvedAreaSolid_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_RevolvedAreaSolid
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRevolvedAreaSolid_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_RevolvedAreaSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRevolvedAreaSolid_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWRevolvedAreaSolid

# Register RWStepShape_RWRevolvedAreaSolid in _RWStepShape:
_RWStepShape.RWStepShape_RWRevolvedAreaSolid_swigregister(RWStepShape_RWRevolvedAreaSolid)

class RWStepShape_RWRevolvedFaceSolid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWRevolvedFaceSolid_swiginit(self, _RWStepShape.new_RWStepShape_RWRevolvedFaceSolid(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_RevolvedFaceSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRevolvedFaceSolid_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_RevolvedFaceSolid
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRevolvedFaceSolid_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_RevolvedFaceSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRevolvedFaceSolid_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWRevolvedFaceSolid

# Register RWStepShape_RWRevolvedFaceSolid in _RWStepShape:
_RWStepShape.RWStepShape_RWRevolvedFaceSolid_swigregister(RWStepShape_RWRevolvedFaceSolid)

class RWStepShape_RWRightAngularWedge(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWRightAngularWedge_swiginit(self, _RWStepShape.new_RWStepShape_RWRightAngularWedge(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_RightAngularWedge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRightAngularWedge_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_RightAngularWedge
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRightAngularWedge_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_RightAngularWedge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRightAngularWedge_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWRightAngularWedge

# Register RWStepShape_RWRightAngularWedge in _RWStepShape:
_RWStepShape.RWStepShape_RWRightAngularWedge_swigregister(RWStepShape_RWRightAngularWedge)

class RWStepShape_RWRightCircularCone(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWRightCircularCone_swiginit(self, _RWStepShape.new_RWStepShape_RWRightCircularCone(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_RightCircularCone

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRightCircularCone_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_RightCircularCone
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRightCircularCone_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_RightCircularCone

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRightCircularCone_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWRightCircularCone

# Register RWStepShape_RWRightCircularCone in _RWStepShape:
_RWStepShape.RWStepShape_RWRightCircularCone_swigregister(RWStepShape_RWRightCircularCone)

class RWStepShape_RWRightCircularCylinder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWRightCircularCylinder_swiginit(self, _RWStepShape.new_RWStepShape_RWRightCircularCylinder(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_RightCircularCylinder

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRightCircularCylinder_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_RightCircularCylinder
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRightCircularCylinder_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_RightCircularCylinder

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWRightCircularCylinder_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWRightCircularCylinder

# Register RWStepShape_RWRightCircularCylinder in _RWStepShape:
_RWStepShape.RWStepShape_RWRightCircularCylinder_swigregister(RWStepShape_RWRightCircularCylinder)

class RWStepShape_RWSeamEdge(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWSeamEdge_swiginit(self, _RWStepShape.new_RWStepShape_RWSeamEdge(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads seamedge.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_SeamEdge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSeamEdge_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_SeamEdge
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSeamEdge_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes seamedge.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_SeamEdge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSeamEdge_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWSeamEdge

# Register RWStepShape_RWSeamEdge in _RWStepShape:
_RWStepShape.RWStepShape_RWSeamEdge_swigregister(RWStepShape_RWSeamEdge)

class RWStepShape_RWShapeDefinitionRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWShapeDefinitionRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWShapeDefinitionRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads shapedefinitionrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ShapeDefinitionRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeDefinitionRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_ShapeDefinitionRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeDefinitionRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes shapedefinitionrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ShapeDefinitionRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeDefinitionRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWShapeDefinitionRepresentation

# Register RWStepShape_RWShapeDefinitionRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWShapeDefinitionRepresentation_swigregister(RWStepShape_RWShapeDefinitionRepresentation)

class RWStepShape_RWShapeDimensionRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWShapeDimensionRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWShapeDimensionRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads shapedimensionrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ShapeDimensionRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeDimensionRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_ShapeDimensionRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeDimensionRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes shapedimensionrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ShapeDimensionRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeDimensionRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWShapeDimensionRepresentation

# Register RWStepShape_RWShapeDimensionRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWShapeDimensionRepresentation_swigregister(RWStepShape_RWShapeDimensionRepresentation)

class RWStepShape_RWShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWShapeRepresentation

# Register RWStepShape_RWShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWShapeRepresentation_swigregister(RWStepShape_RWShapeRepresentation)

class RWStepShape_RWShapeRepresentationWithParameters(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWShapeRepresentationWithParameters_swiginit(self, _RWStepShape.new_RWStepShape_RWShapeRepresentationWithParameters(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads shaperepresentationwithparameters.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ShapeRepresentationWithParameters

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeRepresentationWithParameters_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_ShapeRepresentationWithParameters
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeRepresentationWithParameters_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes shaperepresentationwithparameters.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ShapeRepresentationWithParameters

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShapeRepresentationWithParameters_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWShapeRepresentationWithParameters

# Register RWStepShape_RWShapeRepresentationWithParameters in _RWStepShape:
_RWStepShape.RWStepShape_RWShapeRepresentationWithParameters_swigregister(RWStepShape_RWShapeRepresentationWithParameters)

class RWStepShape_RWShellBasedSurfaceModel(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWShellBasedSurfaceModel_swiginit(self, _RWStepShape.new_RWStepShape_RWShellBasedSurfaceModel(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ShellBasedSurfaceModel

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShellBasedSurfaceModel_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ShellBasedSurfaceModel
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShellBasedSurfaceModel_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ShellBasedSurfaceModel

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWShellBasedSurfaceModel_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWShellBasedSurfaceModel

# Register RWStepShape_RWShellBasedSurfaceModel in _RWStepShape:
_RWStepShape.RWStepShape_RWShellBasedSurfaceModel_swigregister(RWStepShape_RWShellBasedSurfaceModel)

class RWStepShape_RWSolidModel(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWSolidModel_swiginit(self, _RWStepShape.new_RWStepShape_RWSolidModel(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_SolidModel

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSolidModel_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_SolidModel

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSolidModel_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWSolidModel

# Register RWStepShape_RWSolidModel in _RWStepShape:
_RWStepShape.RWStepShape_RWSolidModel_swigregister(RWStepShape_RWSolidModel)

class RWStepShape_RWSolidReplica(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWSolidReplica_swiginit(self, _RWStepShape.new_RWStepShape_RWSolidReplica(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_SolidReplica

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSolidReplica_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_SolidReplica
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSolidReplica_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_SolidReplica

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSolidReplica_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWSolidReplica

# Register RWStepShape_RWSolidReplica in _RWStepShape:
_RWStepShape.RWStepShape_RWSolidReplica_swigregister(RWStepShape_RWSolidReplica)

class RWStepShape_RWSphere(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWSphere_swiginit(self, _RWStepShape.new_RWStepShape_RWSphere(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Sphere

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSphere_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_Sphere
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSphere_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Sphere

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSphere_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWSphere

# Register RWStepShape_RWSphere in _RWStepShape:
_RWStepShape.RWStepShape_RWSphere_swigregister(RWStepShape_RWSphere)

class RWStepShape_RWSubedge(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWSubedge_swiginit(self, _RWStepShape.new_RWStepShape_RWSubedge(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads subedge.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Subedge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSubedge_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_Subedge
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSubedge_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes subedge.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Subedge

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSubedge_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWSubedge

# Register RWStepShape_RWSubedge in _RWStepShape:
_RWStepShape.RWStepShape_RWSubedge_swigregister(RWStepShape_RWSubedge)

class RWStepShape_RWSubface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWSubface_swiginit(self, _RWStepShape.new_RWStepShape_RWSubface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads subface.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Subface

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSubface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepShape_Subface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSubface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes subface.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Subface

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSubface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWSubface

# Register RWStepShape_RWSubface in _RWStepShape:
_RWStepShape.RWStepShape_RWSubface_swigregister(RWStepShape_RWSubface)

class RWStepShape_RWSweptAreaSolid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWSweptAreaSolid_swiginit(self, _RWStepShape.new_RWStepShape_RWSweptAreaSolid(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_SweptAreaSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSweptAreaSolid_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_SweptAreaSolid
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSweptAreaSolid_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_SweptAreaSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSweptAreaSolid_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWSweptAreaSolid

# Register RWStepShape_RWSweptAreaSolid in _RWStepShape:
_RWStepShape.RWStepShape_RWSweptAreaSolid_swigregister(RWStepShape_RWSweptAreaSolid)

class RWStepShape_RWSweptFaceSolid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWSweptFaceSolid_swiginit(self, _RWStepShape.new_RWStepShape_RWSweptFaceSolid(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_SweptFaceSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSweptFaceSolid_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_SweptFaceSolid
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSweptFaceSolid_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_SweptFaceSolid

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWSweptFaceSolid_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWSweptFaceSolid

# Register RWStepShape_RWSweptFaceSolid in _RWStepShape:
_RWStepShape.RWStepShape_RWSweptFaceSolid_swigregister(RWStepShape_RWSweptFaceSolid)

class RWStepShape_RWToleranceValue(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWToleranceValue_swiginit(self, _RWStepShape.new_RWStepShape_RWToleranceValue(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ToleranceValue

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWToleranceValue_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_ToleranceValue
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWToleranceValue_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ToleranceValue

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWToleranceValue_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWToleranceValue

# Register RWStepShape_RWToleranceValue in _RWStepShape:
_RWStepShape.RWStepShape_RWToleranceValue_swigregister(RWStepShape_RWToleranceValue)

class RWStepShape_RWTopologicalRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWTopologicalRepresentationItem_swiginit(self, _RWStepShape.new_RWStepShape_RWTopologicalRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_TopologicalRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTopologicalRepresentationItem_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_TopologicalRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTopologicalRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWTopologicalRepresentationItem

# Register RWStepShape_RWTopologicalRepresentationItem in _RWStepShape:
_RWStepShape.RWStepShape_RWTopologicalRepresentationItem_swigregister(RWStepShape_RWTopologicalRepresentationItem)

class RWStepShape_RWTorus(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWTorus_swiginit(self, _RWStepShape.new_RWStepShape_RWTorus(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Torus

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTorus_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_Torus
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTorus_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Torus

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTorus_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWTorus

# Register RWStepShape_RWTorus in _RWStepShape:
_RWStepShape.RWStepShape_RWTorus_swigregister(RWStepShape_RWTorus)

class RWStepShape_RWTransitionalShapeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWTransitionalShapeRepresentation_swiginit(self, _RWStepShape.new_RWStepShape_RWTransitionalShapeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_TransitionalShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTransitionalShapeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_TransitionalShapeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTransitionalShapeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_TransitionalShapeRepresentation

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTransitionalShapeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWTransitionalShapeRepresentation

# Register RWStepShape_RWTransitionalShapeRepresentation in _RWStepShape:
_RWStepShape.RWStepShape_RWTransitionalShapeRepresentation_swigregister(RWStepShape_RWTransitionalShapeRepresentation)

class RWStepShape_RWTypeQualifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWTypeQualifier_swiginit(self, _RWStepShape.new_RWStepShape_RWTypeQualifier(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_TypeQualifier

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTypeQualifier_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_TypeQualifier

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWTypeQualifier_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWTypeQualifier

# Register RWStepShape_RWTypeQualifier in _RWStepShape:
_RWStepShape.RWStepShape_RWTypeQualifier_swigregister(RWStepShape_RWTypeQualifier)

class RWStepShape_RWValueFormatTypeQualifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWValueFormatTypeQualifier_swiginit(self, _RWStepShape.new_RWStepShape_RWValueFormatTypeQualifier(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads valueformattypequalifier.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_ValueFormatTypeQualifier

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWValueFormatTypeQualifier_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes valueformattypequalifier.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_ValueFormatTypeQualifier

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWValueFormatTypeQualifier_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWValueFormatTypeQualifier

# Register RWStepShape_RWValueFormatTypeQualifier in _RWStepShape:
_RWStepShape.RWStepShape_RWValueFormatTypeQualifier_swigregister(RWStepShape_RWValueFormatTypeQualifier)

class RWStepShape_RWVertex(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWVertex_swiginit(self, _RWStepShape.new_RWStepShape_RWVertex(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_Vertex

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWVertex_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_Vertex

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWVertex_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWVertex

# Register RWStepShape_RWVertex in _RWStepShape:
_RWStepShape.RWStepShape_RWVertex_swigregister(RWStepShape_RWVertex)

class RWStepShape_RWVertexLoop(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWVertexLoop_swiginit(self, _RWStepShape.new_RWStepShape_RWVertexLoop(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_VertexLoop

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWVertexLoop_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_VertexLoop
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWVertexLoop_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_VertexLoop

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWVertexLoop_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWVertexLoop

# Register RWStepShape_RWVertexLoop in _RWStepShape:
_RWStepShape.RWStepShape_RWVertexLoop_swigregister(RWStepShape_RWVertexLoop)

class RWStepShape_RWVertexPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepShape.RWStepShape_RWVertexPoint_swiginit(self, _RWStepShape.new_RWStepShape_RWVertexPoint(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepShape_VertexPoint

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWVertexPoint_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepShape_VertexPoint
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWVertexPoint_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepShape_VertexPoint

        Returns
        -------
        None

        """
        return _RWStepShape.RWStepShape_RWVertexPoint_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepShape.delete_RWStepShape_RWVertexPoint

# Register RWStepShape_RWVertexPoint in _RWStepShape:
_RWStepShape.RWStepShape_RWVertexPoint_swigregister(RWStepShape_RWVertexPoint)





